MethodChannelMacMenuBar constructor

MethodChannelMacMenuBar()

Constructs a MethodChannelMacMenuBar and sets up the method call handler.

This constructor initializes the method channel and sets up the handler for incoming method calls from the native platform.

Implementation

MethodChannelMacMenuBar()
  : _isMacOS = defaultTargetPlatform == TargetPlatform.macOS {
  methodChannel.setMethodCallHandler(_handleMethodCall);
}