setOnSettingsFromMenu abstract method
Sets the callback that will be invoked when the Settings/Preferences menu item is selected.
The callback should return a Future that completes with true if the
operation was handled, or false to allow the default system behavior.
Set to null to restore the default system behavior.
Implementation
void setOnSettingsFromMenu(Future<bool> Function()? callback);